@@ -10,7 +10,7 @@ package Algorithm::AM;
 use strict;
 use warnings;
 # ABSTRACT: Perl extension for Analogical Modeling using a parallel algorithm
-our $VERSION = '2.38'; # VERSION;
+our $VERSION = '2.43'; # VERSION;
 use feature 'state';
 use Path::Tiny;
 use Exporter::Easy (
@@ -214,7 +214,7 @@ sub _create_classify_sub {
 
         #check all input parameters and then save them in $self
         my $opts = _check_classify_opts(@_);
-        for my $opt_name(keys $opts){
+        for my $opt_name(keys %$opts){
             $self->{$opt_name} = $opts->{$opt_name};
         }
 
@@ -347,7 +347,7 @@ Algorithm::AM - Perl extension for Analogical Modeling using a parallel algorith
 
 =head1 VERSION
 
-version 2.38
+version 2.43
 
 =head1 AUTHOR
 
@@ -436,6 +436,8 @@ foreach my $item_number (0 .. $project->num_test_items - 1) {
         %{$self->{subtooutcome}}            = ();
         %{$self->{pointers}}                = ();
         %{$self->{gang}}                    = ();
+        # big ints are used in AM.xs; these consist of an
+        # array of 8 unsigned longs
         foreach (@{$self->{sum}}) {
             $_ = pack "L!8", 0, 0, 0, 0, 0, 0, 0, 0;
         }
@@ -501,6 +503,7 @@ foreach my $item_number (0 .. $project->num_test_items - 1) {
 # line 1600 "call XS"
         $self->_fillandcount(X);
         $grandtotal = $self->{pointers}->{'grandtotal'};
+
         unless ($grandtotal) {
             #TODO: is this tested yet?
             $logger->warn('No data items considered.  No prediction possible.');
